@@ -26,7 +26,7 @@
     #include <asterisk/lock.h>
     #include <asterisk/translate.h>
     #include <asterisk/module.h>
-    #if G72X_ASTERISK >= 110
+    #if G72X_ASTERISK >= 110 && G72X_ASTERISK < 150
         ASTERISK_REGISTER_FILE()
     #endif
     #include <asterisk/logger.h>
@@ -469,8 +469,12 @@ static void g72x_destroy(struct ast_trans_pvt *pvt)
 #if !G72X_BCG729
     ippsFree(state->coder);
     ippsFree(state->scratch_mem);
+#else
+#if G72X_ASTERISK >= 160
+    ast_std_free(state->coder);
 #else
     free(state->coder);
+#endif
 #endif
     /* output the sizes of frames passed to decoder */
     if (option_verbose > 2 && frame_sizes != NULL) {
