@@ -1,9 +1,9 @@
-#!/bin/sh
+#!/bin/sh -xe
 
 b="$1"
 shift
 ./configure --prefix="$b" --localstatedir="$b/var" --sysconfdir="$b/etc" \
-    --without-h323 --without-pwlib --disable-xmldoc --without-sdl "$@" \
+    --without-h323 --without-pwlib --disable-xmldoc --without-sdl --with-jansson-bundled "$@" \
   && nice make -j4 \
   && make install \
   && make samples
